@@ -37,7 +37,7 @@
 #include "imagelib/kpImage.h"
 #include "kpLogCategories.h"
 
-#include <qapplication.h>
+#include <QApplication>
 
 #include <KLocalizedString>
 
@@ -46,7 +46,7 @@
 struct kpToolFloodFillCommandPrivate
 {
     kpImage oldImage;
-    bool fillEntireImage;
+    bool fillEntireImage{false};
 };
 
 //---------------------------------------------------------------------
@@ -100,7 +100,7 @@ void kpToolFloodFillCommand::execute ()
 {
 #if DEBUG_KP_TOOL_FLOOD_FILL && 1
     qCDebug(kpLogCommands) << "kpToolFloodFillCommand::execute() fillEntireImage="
-              << d->fillEntireImage << endl;
+              << d->fillEntireImage;
 #endif
 
     kpDocument *doc = document ();
@@ -141,7 +141,7 @@ void kpToolFloodFillCommand::unexecute ()
 {
 #if DEBUG_KP_TOOL_FLOOD_FILL && 1
     qCDebug(kpLogCommands) << "kpToolFloodFillCommand::unexecute() fillEntireImage="
-              << d->fillEntireImage << endl;
+              << d->fillEntireImage;
 #endif
 
     kpDocument *doc = document ();
